@@ -15,16 +15,16 @@ CONFIG = {
             "LUNAR_DATA_URL": "https://data.dev.apollo-lunar.com",
         },
         "LUNAR": {
-            "TEST_URL": "https://a3hugleaz2-vpce-03604adfb32e11eeb.execute-api.ap-northeast-2.amazonaws.com",
-            "LUNAR_REC_URL": "https://a3hugleaz2-vpce-03604adfb32e11eeb.execute-api.ap-northeast-2.amazonaws.com",
-            "LUNAR_DATA_URL": "https://3fp7y22d53-vpce-03604adfb32e11eeb.execute-api.ap-northeast-2.amazonaws.com",
+            "TEST_URL": "https://2mqu0rhpsc-vpce-0ea0f0c470612df61.execute-api.ap-northeast-2.amazonaws.com",
+            "LUNAR_REC_URL": "https://2mqu0rhpsc-vpce-0ea0f0c470612df61.execute-api.ap-northeast-2.amazonaws.com",
+            "LUNAR_DATA_URL": "https://qu8pnrfq8c-vpce-0ea0f0c470612df61.execute-api.ap-northeast-2.amazonaws.com",
         },
     },
     "STG": {
         "EDD": {
             "TEST_URL": "http://150.6.13.63:8081",
-            "LUNAR_REC_URL": "https://qlcw33mp1g-vpce-00c2fe2f2b87f7ade.execute-api.ap-northeast-2.amazonaws.com",
-            "LUNAR_DATA_URL": "https://fqo6ikf8vg-vpce-00c2fe2f2b87f7ade.execute-api.ap-northeast-2.amazonaws.com",
+            "LUNAR_REC_URL": "https://gm05du691j-vpce-0fa38c61f2c3a311b.execute-api.ap-northeast-2.amazonaws.com",
+            "LUNAR_DATA_URL": "https://cp71v3ev9g-vpce-0fa38c61f2c3a311b.execute-api.ap-northeast-2.amazonaws.com",
             "COPY_DATABASE_URL": "http://150.6.13.9:31771/edd_to_lunar/copy_database",
             "COPY_FILES_URL": "http://150.6.13.9:31771/edd_to_lunar/copy_files",
             "JOB_STATUS_URL": "http://150.6.13.9:31771/edd_to_lunar/job_status",
@@ -35,16 +35,16 @@ CONFIG = {
             "LUNAR_DATA_URL": "https://data.stg.apollo-lunar.com",
         },
         "LUNAR": {
-            "TEST_URL": "https://qlcw33mp1g-vpce-00c2fe2f2b87f7ade.execute-api.ap-northeast-2.amazonaws.com",
-            "LUNAR_REC_URL": "https://qlcw33mp1g-vpce-00c2fe2f2b87f7ade.execute-api.ap-northeast-2.amazonaws.com",
-            "LUNAR_DATA_URL": "https://fqo6ikf8vg-vpce-00c2fe2f2b87f7ade.execute-api.ap-northeast-2.amazonaws.com",
+            "TEST_URL": "https://gm05du691j-vpce-0fa38c61f2c3a311b.execute-api.ap-northeast-2.amazonaws.com",
+            "LUNAR_REC_URL": "https://gm05du691j-vpce-0fa38c61f2c3a311b.execute-api.ap-northeast-2.amazonaws.com",
+            "LUNAR_DATA_URL": "https://cp71v3ev9g-vpce-0fa38c61f2c3a311b.execute-api.ap-northeast-2.amazonaws.com",
         },
     },
     "PRD": {
         "EDD": {
             "TEST_URL": "http://150.6.13.63:8081",
-            "LUNAR_REC_URL": "https://x0eucmpwcd-vpce-02ba2f7cd263a45a1.execute-api.ap-northeast-2.amazonaws.com",
-            "LUNAR_DATA_URL": "https://b9xs1lvk5c-vpce-02ba2f7cd263a45a1.execute-api.ap-northeast2.amazonaws.com/api",
+            "LUNAR_REC_URL": "https://6mxcp1mx6j-vpce-0831759639ca45cb4.execute-api.ap-northeast-2.amazonaws.com",
+            "LUNAR_DATA_URL": "https://qrnczr2pc3-vpce-0831759639ca45cb4.execute-api.ap-northeast-2.amazonaws.com",
             "COPY_DATABASE_URL": "http://150.6.13.9:31771/edd_to_lunar/copy_database",
             "COPY_FILES_URL": "http://150.6.13.9:31771/edd_to_lunar/copy_files",
             "JOB_STATUS_URL": "http://150.6.13.9:31771/edd_to_lunar/job_status",
@@ -55,9 +55,9 @@ CONFIG = {
             "LUNAR_DATA_URL": "https://data.apollo-lunar.com",
         },
         "LUNAR": {
-            "TEST_URL": "https://x0eucmpwcd-vpce-02ba2f7cd263a45a1.execute-api.ap-northeast-2.amazonaws.com",
-            "LUNAR_REC_URL": "https://x0eucmpwcd-vpce-02ba2f7cd263a45a1.execute-api.ap-northeast-2.amazonaws.com",
-            "LUNAR_DATA_URL": "https://b9xs1lvk5c-vpce-02ba2f7cd263a45a1.execute-api.ap-northeast2.amazonaws.com/api",
+            "TEST_URL": "https://6mxcp1mx6j-vpce-0831759639ca45cb4.execute-api.ap-northeast-2.amazonaws.com",
+            "LUNAR_REC_URL": "https://6mxcp1mx6j-vpce-0831759639ca45cb4.execute-api.ap-northeast-2.amazonaws.com",
+            "LUNAR_DATA_URL": "https://qrnczr2pc3-vpce-0831759639ca45cb4.execute-api.ap-northeast-2.amazonaws.com",
         },
     },
 }
